/* Copyright (c) 2014 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 *
 * @defgroup blinky_example_main main.c
 * @{
 * @ingroup blinky_example
 * @brief Blinky Example Application main file.
 *
 */

#include <stdbool.h>
#include <stdint.h>
#include "nrf_delay.h"
#include "nrf_gpio.h"
#include "boards.h"
#include "nrf52.h"
#include "nrf52_bitfields.h"

#define TRIGGER_INTERVAL 1000

void timer_config(void)
{
  NRF_TIMER0->TASKS_STOP = 1;	// Stop timer
  NRF_TIMER0->MODE = TIMER_MODE_MODE_Timer;
  NRF_TIMER0->BITMODE = (TIMER_BITMODE_BITMODE_24Bit << TIMER_BITMODE_BITMODE_Pos);
  NRF_TIMER0->PRESCALER = 4;	// 1us resolution
  NRF_TIMER0->TASKS_CLEAR = 1; // Clear timer
  NRF_TIMER0->CC[0] = TRIGGER_INTERVAL * 5000; 
  NRF_TIMER0->INTENSET = TIMER_INTENSET_COMPARE0_Enabled << TIMER_INTENSET_COMPARE0_Pos;
  NRF_TIMER0->SHORTS = (TIMER_SHORTS_COMPARE0_CLEAR_Enabled << TIMER_SHORTS_COMPARE0_CLEAR_Pos);
  
  NVIC_EnableIRQ(TIMER0_IRQn);
	NRF_TIMER0->TASKS_START = 1;	// Start TIMER
}

void setup() {
  timer_config();
}


void loop() {
	while(1){
		__SEV();
		__WFE();
		__WFE();
	}
		
}

void TIMER0_IRQHandler(void)
{
  if (NRF_TIMER0->EVENTS_COMPARE[0] != 0)
  {

	NRF_POWER->SYSTEMOFF = 1;
    NRF_TIMER0->EVENTS_COMPARE[0] = 0;
		
  }
}

/**
 * @brief Function for application main entry.
 */
 
int main(void)
{
	nrf_delay_ms(1000);
	  setup();
    loop();

	
}
/** @} */
